@@ -32,8 +32,10 @@ ltr_clus<-function(Dat,k){
 			tmp = .ltr_clus2(CDat[[j]])
 			if(length(unique(tmp$cluster))==2){
 				ncc = ncc + 1 
-				clus1=as.matrix(CDat[[j]][tmp$cluster==1,])
-				clus2=as.matrix(CDat[[j]][tmp$cluster==2,])
+				clus1=CDat[[j]][tmp$cluster==1,]
+				clus2=CDat[[j]][tmp$cluster==2,]
+				if(is.null(dim(clus1))) clus1=t(as.matrix(clus1))
+				if(is.null(dim(clus2))) clus2=t(as.matrix(clus2))
 				CDat[[j]]=clus1
 				CDat[[n.clus+ncc]]=clus2
 				nc = nc+1
